pro overcontour, a, xx, yy, grid=grid, NLEVELS = nlev, levels=levels, $
	color = color, title=title, CONTOURSMOOTH=contoursmooth, $
        nolabels = nolabels, xlog=xlog, ylog=ylog

;on_error,2                      ;Return to caller if an error occurs
sz = size(a)			;Size of image
if sz[0] lt 2 then message, 'Parameter not 2D'
gsize=size(grid)
if gsize[0] lt 2 then message, 'Grid invalid'
six = sz[1]			;Image sizes
siy = sz[2]

; axes
nx=n_elements(xx)-1
ny=n_elements(yy)-1
; create axes if not given
if (nx lt 1) then begin
  xx=findgen(six)
  nx=six-1
endif
if (ny lt 1) then begin
  yy=findgen(siy)
  ny=siy-1
endif

; exception handling for NaNs in the data
valid=where(FINITE(a), count)
if count lt 1 then message, "No valid data points found."
validpart=a[valid]
maxval=max(validpart)
minval=min(validpart)

; Logarithmic scale
if keyword_set(xlog) then xxcontour=alog10(xx) else xxcontour=xx
if keyword_set(ylog) then yycontour=alog10(yy) else yycontour=yy

; crop to old image
oldxcenter=(grid[0,1]+grid[2,1])*0.5
oldycenter=(grid[1,1]+grid[3,1])*0.5
validx=where(abs(xxcontour-oldxcenter) lt abs(grid[0,1]-oldxcenter),nx)
validy=where(abs(yycontour-oldycenter) lt abs(grid[1,1]-oldycenter),ny)
; acut=acontour[validx,*]
; acut=acut[*,validy]
xcut=xxcontour[validx]
ycut=yycontour[validy]

; scale of new image
xx1=xcut[0]-(xcut[1]-xcut[0])*0.5
xx2=xcut[nx-1]+(xcut[nx-1]-xcut[nx-2])*0.5
yy1=ycut[0]-(ycut[1]-ycut[0])*0.5
yy2=ycut[ny-1]+(ycut[ny-1]-ycut[ny-2])*0.5

; get size parameters
ax=grid[0,0]
swx=grid[2,0]-ax
ay=grid[1,0]
swy=grid[3,0]-ay

; rescale to old image
px=grid[0,1]
pwx=grid[2,1]-px
py=grid[1,1]
pwy=grid[3,1]-py
xh1=(xx1-px)/pwx*swx+ax
xh2=(xx2-px)/pwx*swx+ax
yh1=(yy1-py)/pwy*swy+ay
yh2=(yy2-py)/pwy*swy+ay

; smoothing step if desired
if n_elements(contoursmooth) gt 0 then begin
  deltax=(xxcontour[nx-1]-xxcontour[0])/(nx-1)
  deltay=(yycontour[ny-1]-yycontour[0])/(ny-1)
  if (n_elements(contoursmooth) eq 1) then begin
    if contoursmooth eq 1 then begin
      binsizex=3
      binsizey=3
    endif else begin
      binsizex=contoursmooth
      binsizey=contoursmooth
    endelse
  endif else begin
      binsizex=contoursmooth[0]
      binsizey=contoursmooth[1]
  endelse
  acontour=min_curve_surf(a,xgrid=[xxcontour[0],deltax],ygrid=[yycontour[0],deltay],$
					/tps,nx=nx*binsizex,ny=ny*binsizey)
  xxcontour=rebin(xxcontour,nx*binsizex)
  yycontour=rebin(yycontour,ny*binsizey)
endif else acontour=a

; Contour level definition
mx = !d.n_colors-1		;Brightest color
				;color vectors
; default
nlevbas=n_elements(levels)
if n_elements(nlev) EQ 0 then begin
	nlev=nlevbas
	if nlev eq 0 then nlev=5
endif

; No contours for constant surface
if maxval eq minval then nlev=0
if nlev gt 0 then begin

; contour colors
if n_elements(color) eq nlev then colors=color*mx else begin
  if n_elements(color) ne 1 then color=0
    if (color le 0) then begin
      colors=intarr(nlev)
      for i=0,(nlev-1)/2 do colors[i]=mx
      for i=(nlev-1)/2+1,nlev-1 do colors[i]=0
    endif else colors=make_array(nlev,value=long(mx*color))
endelse

nodata=0
; Create really equidistant levels
if nlevbas eq 0 then begin
  a0=minval
  da=(maxval-minval)/(nlev+1)
  levels=fltarr(nlev)
  for j=0,nlev-1 do levels[j]=a0+(j+1)*da
endif else begin
  levels=levels[0:nlev-1]
endelse

; Contours in color wedge
if (n_elements(nolabels) eq 0) then begin
 nolabels=0
 if gsize[2] gt 2 then begin
  steps=100
  ax1=[0.0,1.0]
  ax2=fltarr(steps)
  x0=float(grid[0,3])
  dx=(grid[3,3]-x0)/(steps-1)
  feld2=fltarr(2,steps)
  for j=0,steps-1 do begin feld2[0,j]=x0+j*dx & feld2[1,j]=feld2[0,j] & endfor
  for j=0,steps-1 do ax2[j]=x0+j*dx
  contour, feld2, ax1,ax2, /noerase, pos=grid[*,2], /dev, $
        levels = levels, c_color = colors, nodata = nodata, ystyle=5, xstyle=5
  if (levels[0] ge grid[0,3]) and (levels[nlev-1] lt grid[3,3]) then nolabels=1
 endif
endif

if nolabels then labels=make_array(n_elements(levels),value=0) $
 else labels=make_array(n_elements(levels),value=1)

; label size
sz=!p.charsize
if sz ne 0.0 then sz=0.6*sz else sz=0.6

; Now add the contour plot
contour,acontour,xxcontour,yycontour,/noerase,xstyle=5,ystyle=5,$
	xrange=[xx1,xx2], yrange=[yy1,yy2],$
	pos = [xh1,yh1,xh2,yh2],/dev, c_labels=labels, c_charsize=sz, $
	levels = levels, c_colors =  colors, nodata = nodata

endif
; Title
if n_elements(title) gt 0 then $
	xyouts, ax+0.05*swx, ay+0.94*swy, /dev, title, $
	   charsize=!p.charsize*1.2, color=colors[0], charthick=2.0

return
end
