; functions to read the spectra from the files

; isotropic and anisotropic wavelet spectra
function getspectra, name, type, isotropic=diso, weights=feldweights

allfelds=readfits(name+"_allconvolved_"+type+".fits",hdr)
feldiso=reform(allfelds[*,*,0,*])
feldan=reform(allfelds[*,*,1,*])
if (size(allfelds))[3] gt 3 then feldweights=reform(allfelds[*,*,3,*]) $
	 else feldweights=feldiso*0.0+1.0
nscal=(size(feldiso))[3]
diso=fltarr(nscal)
dan=fltarr(nscal)
for i=0,nscal-1 do begin &$
  dnorm=total(feldweights[*,*,i]) &$
  dan[i]=total(feldan[*,*,i]*feldweights[*,*,i],/nan)/dnorm &$
  diso[i]=total(feldiso[*,*,i]*feldweights[*,*,i],/nan)/dnorm &$
endfor

return, dan
end

; angular distribution
function getangles, name, type, isotropic=diso

allfelds=readfits(name+"_allconvolved_"+type+".fits",hdr)
feldiso=reform(allfelds[*,*,0,*])
feldan=reform(allfelds[*,*,1,*])
feldphi=reform(allfelds[*,*,2,*])
if (size(allfelds))[3] gt 3 then feldweights=reform(allfelds[*,*,3,*]) $
	 else feldweights=feldiso*0.0+1.0
nmap=n_elements(feldiso[*,*,0])
nscal=(size(feldiso))[3]

; result fields
philin=reform(feldphi*feldweights,nmap,nscal)
anlin=reform(feldan*feldweights,nmap,nscal)
diso=feldiso*feldweights

return, [[[philin]],[[anlin]]]
end

; degrees of anisotropy
function getdegree, name, type, local=dlocal, weights=feldweights

allfelds=readfits(name+"_allconvolved_"+type+".fits",hdr)
feldiso=reform(allfelds[*,*,0,*])
feldan=reform(allfelds[*,*,1,*])
feldphi=reform(allfelds[*,*,2,*])
if (size(allfelds))[3] gt 3 then feldweights=reform(allfelds[*,*,3,*]) $
	 else feldweights=feldiso*0.0+1.0
nscal=(size(feldiso))[3]

; loop over all scales
dlocal=fltarr(nscal)
dglobal=fltarr(nscal)
icheck=fltarr(nscal)
for i=0,nscal-1 do begin
  icheck[i]=total(feldiso[*,*,i]*feldweights[*,*,i],/nan)
  dlocal[i]=total(feldan[*,*,i]*feldweights[*,*,i],/nan)/icheck[i]
  global=feldan[*,*,i]*exp(complex(0.0,1.0)*feldphi[*,*,i])*feldweights[*,*,i]
  dglobal[i]=abs(total(global,/nan))/total(feldiso[*,*,i]*feldweights[*,*,i],/nan)
endfor
invalid=where(icheck lt 1e-15*max(icheck),count)
if count gt 0 then begin 
        dlocal[invalid]=!values.f_nan
        dglobal[invalid]=!values.f_nan
endif

return, dglobal
end

